@@ -2,7 +2,7 @@
 
 from typing import Dict, List, Union, Tuple
 
-__all__ = ['load_pbn', 'save_pbn', 'pbn_as_text', 'load_lin', 'load_rbn', 'parse_pbn', 'parse_lin', 'save_rbn', 'BoardAsString']
+__all__ = ['load_pbn', 'save_pbn', 'pbn_as_text', 'load_lin', 'load_rbn', 'parse_pbn', 'parse_lin', 'save_rbn', 'create_pbn_board']
 
 import os
 import datetime
@@ -233,7 +233,6 @@ def parse_pbn(file_lines: List[str]) -> List[Event]:
             # elif tag == "Description":
             #     board.description = value
 
-# TODO sort out modifiers
             # Contract
             elif tag == "Contract":
                 if value and value[-1] == 'X':
@@ -636,7 +635,7 @@ def _create_pbn_event(event: Event) -> List[str]:
         output.append(f'[Date "{event_date}"]')
     output.append('')
     for board in event.boards:
-        output.extend(BoardAsString.create_pbn_board(event, board))
+        output.extend(create_pbn_board(event, board))
     return output
 #
 #
@@ -886,40 +885,35 @@ def _parse_lin_hands(cards: str, dealer: str) -> Dict[object, Hand]:
     return hands
 
 
-class BoardAsString(object):
-    def __init__(self):
-        pass
-
-    @staticmethod
-    def create_pbn_board(event: Event, board: Board) -> List[str]:
-        """Return a board as a list of strings in pbn format."""
-        output = [f'[Board "{board.identifier}"]',
-                  f'[West "{board.west}"]',
-                  f'[North "{board.north}"]',
-                  f'[East "{board.east}"]',
-                  f'[South "{board.south}"]',
-                  f'[Dealer "{board.dealer}"]']
-        if board.description:
-            output.append(f'[Description "{board.description}"]')
-        if board.vulnerable:
-            vulnerability = board.vulnerable.replace("Both", "All")
-            output.append(f'[Vulnerable "{vulnerability}"]')
-        output.append(f'[Deal "{board.dealer}:{_get_pbn_deal(board)}"]')
-        if event:
-            output.append(f'[Scoring {_question_from_null(event.scoring_method)}]')
-        output.append(f'[Declarer {_question_from_null(board.contract.declarer)}]')
-        if board.contract.call:
-            question = _question_from_null(board.contract.call.name)
-            output.append(f'[Contract {question}]')
-        if board.auction.calls:
-            output.extend(_create_pbn_auction(board))
-        output.append(f'[Result {_question_from_null(board.result)}]')
-        if board.tricks:
-            output.extend(_create_pbn_play_section(board))
+def create_pbn_board(event: Event, board: Board) -> List[str]:
+    """Return a board as a list of strings in pbn format."""
+    output = [f'[Board "{board.identifier}"]',
+                f'[West "{board.west}"]',
+                f'[North "{board.north}"]',
+                f'[East "{board.east}"]',
+                f'[South "{board.south}"]',
+                f'[Dealer "{board.dealer}"]']
+    if board.description:
+        output.append(f'[Description "{board.description}"]')
+    if board.vulnerable:
+        vulnerability = board.vulnerable.replace("Both", "All")
+        output.append(f'[Vulnerable "{vulnerability}"]')
+    output.append(f'[Deal "{board.dealer}:{_get_pbn_deal(board)}"]')
+    if event:
+        output.append(f'[Scoring {_question_from_null(event.scoring_method)}]')
+    output.append(f'[Declarer {_question_from_null(board.contract.declarer)}]')
+    if board.contract.call:
+        question = _question_from_null(board.contract.call.name)
+        output.append(f'[Contract {question}]')
+    if board.auction.calls:
+        output.extend(_create_pbn_auction(board))
+    output.append(f'[Result {_question_from_null(board.result)}]')
+    if board.tricks:
+        output.extend(_create_pbn_play_section(board))
+    output.append('')
+    if board.play_notes:
+        for key in board.play_notes:
+            note = f'[Note "{key}:{board.play_notes[key]}"]'
+            output.append(note)
         output.append('')
-        if board.play_notes:
-            for key in board.play_notes:
-                note = f'[Note "{key}:{board.play_notes[key]}"]'
-                output.append(note)
-            output.append('')
-        return output
+    return output
