@@ -1,7 +1,10 @@
-"""A class to represent a bridgeobjects Trick,"""
+"""A class to represent a bridgeobjects Trick."""
+
+from typing import List, Union
 
 from .constants import SEATS, CARD_NAMES
 from .card import Card
+from .suit import Suit
 
 
 __all__ = ['Trick',]
@@ -9,37 +12,31 @@ __all__ = ['Trick',]
 
 class Trick(object):
     """A trick object for the board player."""
-    def __init__(self, cards=None):
-        # if not isinstance(index, int):
-        #     raise TypeError('Index must be integer')
-        # if index not in range(13):
-        #     raise ValueError('Invalid index')
+    def __init__(self, cards: Union[List[Card], None]=None):
         if not cards:
             cards = []
-        # self.index = index
-        self.cards = cards  # a list of Card instances
-        self._start_suit = None
-        self._leader = None
-        self.winner = None
+        self._cards = self._card_setter(cards) # a list of Card instances
+        if self.cards:
+            self._start_suit = self._cards[0].suit
+        else:
+            self._start_suit = None
+        self._leader = ''
+        self.winner = ''
         self.note_keys = ['' for _ in range(4)]
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """ A repr string for the object."""
-        # cards = ', '.join([card.name for card in self._cards])
-        # return f'Trick({cards})'
         cards = ', '.join([f'"{card.name}"' for card in self._cards])
-        # text = (f'Trick: Leader: {self._leader}, winner: {self.winner}, '
-        #         f'cards: {cards}')
         return f'Trick(cards={cards})'
 
-    def __str__(self):
+    def __str__(self) -> str:
         """ A str string for the object."""
         cards = ', '.join([card.name for card in self._cards])
         text = (f'Trick: Leader: {self._leader}, winner: {self.winner}, '
                 f', cards: {cards}')
         return text
 
-    def complete(self, trump_suit=None):
+    def complete(self, trump_suit: Union[Suit, None]=None):
         """Complete the trick fields."""
         if len(self._cards) != 4:
             raise ValueError(f'Trick contains {len(self._cards)} card(s)')
@@ -63,17 +60,21 @@ class Trick(object):
         self.winner = SEATS[(leader + winner_seat) % 4]
 
     @property
-    def cards(self):
+    def cards(self) -> List[Card]:
         """Return the cards as a list."""
         return self._cards
 
     @cards.setter
-    def cards(self, value):
+    def cards(self, value: Union[List[Card], List[str]]):
         """Set the value of the cards list."""
-        if not isinstance(value, list):
+        self._cards = self._card_setter(value)
+
+    def _card_setter(self, cards: Union[List[Card], List[str]]):
+        """Return the cards list."""
+        if not isinstance(cards, list):
             raise TypeError('Cards not a list.')
         card_list = []
-        for index, card in enumerate(value):
+        for index, card in enumerate(cards):
             if isinstance(card, str):
                 if card not in CARD_NAMES:
                     raise ValueError('Invalid card name')
@@ -83,15 +84,16 @@ class Trick(object):
             if index == 0:
                 self._start_suit = card.suit
             card_list.append(card)
-        self._cards = card_list
-        
+        return card_list
+
+
     @property
-    def leader(self):
+    def leader(self) -> str:
         """Return  seat of the leader as a string."""
         return self._leader
 
     @leader.setter
-    def leader(self, value):
+    def leader(self, value: str):
         """Set the value of the leader as a string."""
         if value:
             if not isinstance(value, str):
@@ -101,6 +103,6 @@ class Trick(object):
             self._leader = value
 
     @property
-    def start_suit(self):
+    def start_suit(self) -> Union[Suit, None]:
         """Return the Suit of the lead card in the trick."""
         return self._start_suit
